// TODO
// A `Circle` class/function that can be invoked as :
// const c = new Circle();
// It should contain at least 3 hidden fields `x`, `y`, and `radius`.
export class Circle{
    #x;
    #y;
    #radius;

    /**
     * Constructeur de la classe Circle
     * @param x
     * @param y
     * @param radius
     */
    constructor(x=0, y=0, radius=1)
    {
        this.#x = x;
        this.#y = y;
        this.#radius = radius;
    }

    /**
     * Getter de x de y
     * @returns {*[]}
     */
    get coords() {
        return [this.#x, this.#y];
    }

    /**
     * Getter du rayon
     * @returns {*}
     */
    get radius() {
        return this.#radius;
    }

    /**
     * Setter du rayon
     * @param radius
     */
    set radius(radius)
    {
        if(typeof radius !== 'number')
            throw new Error('le rayon du cercle doit etre un nombre');
        if(radius<0)
            throw new Error('le rayon du cercle doit etre positif');
        this.#radius = radius;
    }

    /**
     * Modifie les coordonnees
     * @param x
     * @param y
     */
    moveTo(x,y){
        this.#x = x;
        this.#y = y;
    }

    /**
     * getter de l'aire
     * @returns {number}
     */
    get area()
    {
        let radius = this.radius;
        return Math.PI* radius * radius;
    }

    /**
     * Setter de l'aire
     * @param area
     */
    set area(area){
        if(typeof area !== 'number')
            throw new Error('l\'aire doit etre un nombre');

        if(area<0)
            throw new Error('l\'aire doit etre positif');

        this.#radius = Math.sqrt(area/Math.PI);
    }

    /**
     * calcule la ditance entre le cercle c1 et c2
     * @param c1
     * @param c2
     * @returns {number}
     */
    static distance(c1, c2)
    {
        const [x1, y1] = c1.coords;
        const [x2, y2] = c2.coords;
        const dx = x2-x1;
        const dy = y2-y1;
        return Math.sqrt(dx*dx + dy*dy);
    }

    /**
     * teste si deux cercles c1 et c2 ont subit une intersection
     * @param c1
     * @param c2
     * @returns {boolean}
     */
    static doIntersect(c1, c2)
    {
        return Circle.distance(c1, c2) - (c1.radius + c2.radius) <0;
    }

}



